@@ -1,8 +1,5 @@
 package App::yamlsel;
 
-our $DATE = '2020-04-29'; # DATE
-our $VERSION = '0.008'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -10,6 +7,11 @@ use warnings;
 use App::CSelUtils;
 use Scalar::Util qw(refaddr);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-11'; # DATE
+our $DIST = 'App-yamlsel'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our %SPEC;
 
 sub _encode_yaml {
@@ -80,7 +82,7 @@ App::yamlsel - Select YAML elements using CSel (CSS-selector-like) syntax
 
 =head1 VERSION
 
-This document describes version 0.008 of App::yamlsel (from Perl distribution App-yamlsel), released on 2020-04-29.
+This document describes version 0.009 of App::yamlsel (from Perl distribution App-yamlsel), released on 2024-07-11.
 
 =head1 SYNOPSIS
 
@@ -91,7 +93,7 @@ This document describes version 0.008 of App::yamlsel (from Perl distribution Ap
 
 Usage:
 
- yamlsel(%args) -> [status, msg, payload, meta]
+ yamlsel(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Select YAML elements using CSel (CSS-selector-like) syntax.
 
@@ -103,8 +105,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<expr> => I<str>
 
+(No description)
+
 =item * B<file> => I<filename> (default: "-")
 
+(No description)
+
 =item * B<node_actions> => I<array[str]> (default: ["print_as_string"])
 
 Specify action(s) to perform on matching nodes.
@@ -178,12 +184,12 @@ C<root> will return a single node which is the root node.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -195,6 +201,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-yamlse
 
 Source repository is at L<https://github.com/perlancar/perl-App-yamlsel>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2020, 2019, 2016 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-yamlsel>
@@ -203,15 +238,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
